// components/privacyModal/privacyModal.js
Component({
  /**
   * 组件的属性列表
   */
  properties: {
    // 是否显示弹窗
    isShowPrivacyModal: {
      type: Boolean,
      value: false,
      observer: function (newVal) {
        this.setData({
          isShowModal: newVal,
        });
      },
    },
  },

  resolvePrivacyAuthorization: null, // onNeedPrivacyAuthorization 的首个回调参数，是一个接口函数

  /**
   * 组件的初始数据
   */
  data: {
    name: "Hooli Partner", // 小程序名称
    isShowModal: false, // 是否显示弹窗
  },

  ready() {
    // 检测是否需要隐私协议授权
    this.isNeedPrivacyAuthorization();
  },

  /**
   * 组件的方法列表
   */
  methods: {
    // 检测是否需要隐私协议授权
    isNeedPrivacyAuthorization() {
      if (wx.onNeedPrivacyAuthorization) {
        wx.onNeedPrivacyAuthorization((resolve, eventInfo) => {
          // 需要用户同意隐私授权时
          // 弹出开发者自定义的隐私授权弹窗
          this.setData({
            isShowModal: true,
          });
          this.resolvePrivacyAuthorization = resolve;
        });
      }
    },
    // 打开隐私协议页面
    handleOpenPrivacyContract() {
      // 打开隐私协议页面
      if (wx.openPrivacyContract) {
        wx.openPrivacyContract({
          success: (e) => {}, // 打开成功
          fail: (e) => {
            // 打开失败
            wx.showToast({
              title: "打开失败，请重试",
              icon: "none",
              duration: 2000,
            });
          },
        });
      }
    },
    // 用户同意隐私协议事件回调
    handleAgreePrivacyAuthorization(e) {
      // 用户点击了同意，之后所有已声明过的隐私接口和组件都可以调用了
      // 上报同意事件
      this.resolvePrivacyAuthorization &&
        this.resolvePrivacyAuthorization({
          buttonId: "agree-btn",
          event: "agree",
        });
      // 关闭弹窗
      this.setData({
        isShowModal: false,
      });
      // 组件外部事件预留
      this.triggerEvent("confirm");
    },
    // 用户点击拒绝
    handleClickRefuse() {
      wx.showModal({
        title: "重要提示",
        content: "如您拒绝，将无法使用隐私协议中的相关功能，确定要拒绝吗？",
        cancelText: "再想想",
        confirmText: "残忍拒绝",
        success: (res) => {
          // 确定拒绝
          if (res && res.confirm) {
            // 上报拒绝事件
            this.resolvePrivacyAuthorization &&
              this.resolvePrivacyAuthorization({ event: "disagree" });
            // 关闭弹窗
            this.setData({
              isShowModal: false,
            });
            // 组件外部事件预留
            this.triggerEvent("refuse");
          }
        },
        fail: () => {},
        complete: () => {},
      });
    },
    // 关闭弹窗
    handleCloseModal() {
      this.setData({
        isShowModal: false,
      });
    },
  },
});
