const {
  api_leads_selects,
  api_leads_add,
  api_leads_share_add
} = require('../../utils/api.js');
const {
  net
} = require('../../utils/net.js');
const util = require('../../utils/util.js');
Page({

  /**
   * 页面的初始数据
   */
  data: {
    liveTimeText: "",
    degreeText: "",
    rentTimeUnitText: "",
    cityName: "",
    countryName: "",
    schoolName: "",
    isShare: false,
    loadingFlag: false,
    isBtnDisabled: false, // 提交按钮是否禁用 true 禁用 false 未禁用
    leadsSelectsObj: {},
    sexArr: [{
      sex: 1,
      name: "男",
      icon: 'icon-hooli-male'
    }, {
      sex: 2,
      name: "女",
      icon: 'icon-xingzhuangx'
    }],
    formData: {
      customerName: "",
      prefixMobile: "",
      mobile: "",
      wechatId: "",
      email: "",
      sex: 1,
      countryId: "",
      cityId: "",
      remark: "",
      scene: "",
      schoolId: "",
      rentTime: "",
      rentTimeUnit: "",
      liveTime: "",
      degree: "",
      professional: ""
    }
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    const {
      scene
    } = options;
    const userInfo = util.getStorageSync('userInfo');
    if (options && scene) {
      if (userInfo && userInfo.scene && scene === userInfo.scene) {
        this.setData({
          isShare: false,
        })
      } else {
        this.setData({
          [`formData.scene`]: scene,
          isShare: true,
        })
      }
    }
    this.getLeadsSelects()
  },

  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady: function () {
    wx.setNavigationBarTitle({
      title: this.data.isShare ? '租赁意向表' : '新增客户'
    })
  },
  getLeadsSelects() {
    let params = {
      url: api_leads_selects
    }
    this.setData({
      loadingFlag: true
    })
    net.req(params).then((res) => {
      const { prefixMobile, rentTimeUnitSels } = res.data
      // 处理手机号前缀默认值
      let prefixMobileValue = ""
      if (prefixMobile && Array.isArray(prefixMobile) && prefixMobile.length) {
        prefixMobile.forEach((item, index) => {
          if ("86" == item.value || "+86" == item.value) { // 默认为中国+86
            prefixMobileValue = item.value
          }
        })
      }
      // 处理租期单位默认值
      let rentTimeUnitText = ""
      let rentTimeUnitValue = ""
      if (rentTimeUnitSels && Array.isArray(rentTimeUnitSels) && rentTimeUnitSels.length) {
        rentTimeUnitSels.forEach(item => {
          if ('周' === item.name || '周' === item.value) {
            rentTimeUnitText = item.name
            rentTimeUnitValue = item.value
          }
        })
      }
      this.setData({
        leadsSelectsObj: res.data,
        loadingFlag: false,
        rentTimeUnitText: rentTimeUnitText,
        [`formData.rentTimeUnit`]: rentTimeUnitValue,
        [`formData.prefixMobile`]: prefixMobileValue
      })
    })
  },
  bindCustomerName(e) {
    const value = e.detail.value
    this.setData({
      [`formData.customerName`]: value
    })
  },
  bindPrefixMobilePickerChange(e) {
    const {
      value
    } = this.data.leadsSelectsObj.prefixMobile[e.detail.value]
    this.setData({
      [`formData.prefixMobile`]: value
    })
  },
  bindMobile(e) {
    this.setData({
      [`formData.mobile`]: e.detail.value
    })
  },
  bindWechatId(e) {
    this.setData({
      [`formData.wechatId`]: e.detail.value
    })
  },
  bindEmail(e) {
    this.setData({
      [`formData.email`]: e.detail.value
    })
  },
  sexTap(e) {
    this.setData({
      [`formData.sex`]: e.currentTarget.dataset.sex
    })
  },
  bindPickerChange(e) {
    const {
      name,
      value
    } = this.data.leadsSelectsObj.rentTimeUnitSels[e.detail.value]

    this.setData({
      [`formData.rentTimeUnit`]: value,
      rentTimeUnitText: name
    })
  },
  bindDegreeChange(e) {
    const {
      name,
      value
    } = this.data.leadsSelectsObj.degreeSels[e.detail.value]

    this.setData({
      [`formData.degree`]: value,
      degreeText: name
    })
  },
  liveTimeChange(e) {
    const {
      value
    } = e.detail
    this.setData({
      liveTimeText: value,
      [`formData.liveTime`]: value ? new Date(value.split('-').join("/")).getTime() : ''
    })
  },
  bindRentTime(e) {
    this.setData({
      [`formData.rentTime`]: e.detail.value
    })
  },
  bindProfessional(e) {
    this.setData({
      [`formData.professional`]: e.detail.value
    })
  },
  bindRemark(e) {
    this.setData({
      [`formData.remark`]: e.detail.value
    })
  },
  // 选择国家城市
  goSelectCountry() {
    if (this.data.isBtnDisabled) return;
    wx.navigateTo({
      url: '/pages/selectCity/selectCity',
      events: {
        selectedCityEvent: (selItem) => {
          const { formData } = this.data;
          if (selItem.countryId !== formData.countryId || selItem.cityId !== formData.cityId && formData.schoolId && this.data.schoolName) {
            this.setData({
              cityName: selItem.cityName,
              countryName: selItem.countryName,
              schoolName: "",
              [`formData.cityId`]: selItem.cityId,
              [`formData.countryId`]: selItem.countryId,
              [`formData.schoolId`]: ""
            })
          } else {
            this.setData({
              cityName: selItem.cityName,
              countryName: selItem.countryName,
              [`formData.cityId`]: selItem.cityId,
              [`formData.countryId`]: selItem.countryId,
            })
          }
        }
      }
    })
  },
  // 选择国家城市 -- 搜索结果
  getSelectedCountryCity(selItem) {
    const { formData } = this.data;
    if (selItem.countryId !== formData.countryId || selItem.cityId !== formData.cityId && formData.schoolId && this.data.schoolName) {
      this.setData({
        cityName: selItem.cityName,
        countryName: selItem.countryName,
        schoolName: "",
        [`formData.cityId`]: selItem.cityId,
        [`formData.countryId`]: selItem.countryId,
        [`formData.schoolId`]: ""
      })
    } else {
      this.setData({
        cityName: selItem.cityName,
        countryName: selItem.countryName,
        [`formData.cityId`]: selItem.cityId,
        [`formData.countryId`]: selItem.countryId,
      })
    }
  },
  // 选择学校
  goSelectSchool() {
    const {
      countryId,
      cityId
    } = this.data.formData
    if (this.data.isBtnDisabled) return;
    if (countryId && cityId) {
      wx.navigateTo({
        url: `/pages/selectSchool/selectSchool?countryId=${countryId}&cityId=${cityId}`,
        events: {
          selectedSchoolEvent: (selItem) => {
            this.setData({
              schoolName: selItem.schoolName,
              [`formData.schoolId`]: selItem.schoolId
            })
          }
        }
      })
    } else {
      wx.showToast({
        title: '请先选择意向城市',
        icon: 'none',
        duration: 2000
      })
    }
  },
  showErrorMsg(msg) {
    wx.showToast({
      title: msg,
      icon: 'none',
      duration: 2000
    })
  },
  submitDataTap() {
    const {
      customerName,
      prefixMobile,
      mobile,
      wechatId,
      email,
      countryId,
      cityId,
      rentTime,
      rentTimeUnit,
      liveTime
    } = this.data.formData

    if (!customerName) {
      return this.showErrorMsg('客户姓名不能为空')
    }
    if (!(mobile || wechatId || email)) {
      return this.showErrorMsg('请填写一项客户联系方式')
    }
    if (mobile && !prefixMobile) {
      return this.showErrorMsg('区号不能为空')
    }
    if (email && (!util.validator.checkEmail(email))) {
      return this.showErrorMsg('邮箱格式不正确')
    }
    if (!(countryId && cityId)) {
      return this.showErrorMsg('意向城市不能为空')
    }
    if (!liveTime) {
      return this.showErrorMsg('入住时间不能为空')
    }
    if (!rentTime) {
      return this.showErrorMsg('租期不能为空')
    }
    if (!rentTimeUnit) {
      return this.showErrorMsg('请选择租期单位')
    }
    this.creatTradeHandle()
  },
  creatTradeHandle() {
    if (!this.data.isBtnDisabled) {
      this.setData({
        isBtnDisabled: true
      })
      wx.showLoading({
        title: "努力提交中...",
        mask: true
      });
      let params = {
        url: this.data.isShare ? api_leads_share_add : api_leads_add,
        data: this.data.formData,
      }
      net.req(params, true).then((res) => {
        if (parseInt(res.code) === 0) {
          wx.showToast({
            title: '保存成功',
            icon: 'success',
            duration: 2000
          })
          if (this.data.isShare) {
            wx.redirectTo({
              url: '/pages/collectionSucceed/collectionSucceed',
            })
          } else {
            let pages = getCurrentPages();
            let prevPage = pages[pages.length - 2];
            if (prevPage && prevPage.initListCallBack) {
              prevPage.initListCallBack();
              wx.navigateBack();
            } else {
              wx.redirectTo({
                url: '/pages/leadslist/leadslist',
              })
            }
          }
          wx.hideLoading();
          this.setData({
            isBtnDisabled: false
          })
        } else {
          wx.hideLoading();
          wx.showToast({
            title: res.msg || 'error',
            icon: 'none',
            duration: 2000
          });
          this.setData({
            isBtnDisabled: false
          })
        }
      }, e => {
        wx.hideLoading();
        wx.showToast({
          title: e.msg || 'error',
          icon: 'none',
          duration: 2000
        });
        this.setData({
          isBtnDisabled: false
        })
      }).catch((err) => {
        wx.hideLoading();
        wx.showToast({
          title: err.msg || 'error',
          icon: 'none',
          duration: 2000
        });
        this.setData({
          isBtnDisabled: false
        })
      })
    }
  }

})