const {
  api_leads_list,
  api_get_qrcode,
} = require('../../utils/api.js');
const {
  net
} = require('../../utils/net.js');
const util = require('../../utils/util.js');
Page({
  data: {
    isFliter: false,
    avatar: "https://static.hoolihome.com/www/assets/images/code_hooli.png",
    pattern: '',
    barcodeImgUrl: "",
    showAddFlag: false,
    keyWord: "",
    loadingFlag: true,
    dataArr: [],
    totalCount: null,
    resultData: {}
  },
  pageData: {
    page: 1,
    limit: 10
  },
  onLoad: function (options) {
    const {
      time
    } = options
    if (time) {
      this.setData({
        [`resultData.createTime`]: JSON.stringify({
          searchTimeType: time
        }),
        isFliter: true,
      })
    }
    this.getData();
  },
  onShareAppMessage: function () {
    let userInfo = util.getStorageSync('userInfo')
    let {
      scene
    } = userInfo;
    return {
      title: '租房意向收集表',
      imageUrl: 'https://static.hoolihome.com/weapp/distributor/leadShare.png?x-oss-process=image/resize,w_320',
      path: `/pages/leadscollection/leadscollection?scene=${scene}`,
      success: (res) => {
        wx.showToast({
          title: '分享成功',
          icon: 'none'
        })
      }
    }
  },
  // 获取数据
  getData(isShowLoading = true) {
    wx.stopPullDownRefresh()
    const { totalCount, dataArr } = this.data
    if ((totalCount && parseInt(totalCount)) === dataArr.length) {
      return false
    }
    this.setData({
      loadingFlag: isShowLoading
    })
    let params = {
      url: api_leads_list,
      data: {
        page: this.pageData.page,
        limit: this.pageData.limit
      }
    }
    params.data = Object.assign({}, params.data, this.data.resultData)
    if (this.data.keyWord) {
      params.data.keyWord = this.data.keyWord
    }
    net.req(params).then((res) => {
      this.setData({
        loadingFlag: false,
        dataArr: this.pageData.page > 1 ? this.data.dataArr.concat(res.data.list) : res.data.list || [],
        totalCount: res.data.pages.totalCount
      })
    })
  },
  // 下拉刷新
  onPullDownRefresh: function () {
    this.setData({
      totalCount: null,
    }, () => {
      this.pageData.page = 1
      this.getData();
    })
  },
  // 加载更多
  onReachBottom: function () {
    this.pageData.page += 1
    this.getData(false)
  },
  // 搜索
  toSearch() {
    wx.navigateTo({
      url: `/pages/leadslistsearch/leadslistsearch?resultData=${JSON.stringify(this.data.resultData)}`
    })
  },
  // 详情页
  showDetail(options) {
    // 把未读的new改变成已读
    const {
      currentIndex,
      item
    } = options.currentTarget.dataset;
    const isNew = `dataArr[${currentIndex}].isNew`;
    this.setData({
      [isNew]: 0
    });
    wx.navigateTo({
      url: `/pages/leadsdetail/leadsdetail?id=${item.id}`
    })
  },
  copyWXAction(e) {
    const {
      currentWx
    } = e.currentTarget.dataset;
    if (currentWx && currentWx.length) {
      wx.setClipboardData({
        data: currentWx,
        success(res) { }
      })
    }
  },
  tapTelAction(e) {
    const {
      tel
    } = e.currentTarget.dataset;
    let _this = this;
    let systemInfo = util.getStorageSync('systemInfo');
    if (!systemInfo) {
      systemInfo = wx.getSystemInfoSync();
      if (systemInfo) {
        wx.setStorageSync('systemInfo', systemInfo);
      }
    }
    let {
      system
    } = systemInfo;
    if (system.toLowerCase().indexOf('ios') !== -1) {
      wx.makePhoneCall({
        phoneNumber: tel,
        success() { },
        fail() { },
        complete() { }
      });
    } else {
      wx.showActionSheet({
        itemList: [tel],
        success(res) {
          if (res.tapIndex === 0) {
            wx.makePhoneCall({
              phoneNumber: _this.data.phone,
              success() { },
              fail() { },
              complete() { }
            });
          }
        }
      })
    }
  },
  clueTypeChange(e) {
    this.setData({
      clueTypeIndex: e.currentTarget.dataset.type
    })
  },
  // 实时搜索
  touchSearch(event) {
    let _this = this;
    clearTimeout(this.timer)
    this.timer = setTimeout(() => {
      _this.searchHandle(event);
    }, 500)
  },
  // 完成搜索
  searchHandle(event) {
    this.setData({
      totalCount: null,
      keyWord: event.detail.value,
    }, () => {
      this.pageData.page = 1
      this.getData();
    })
  },
  // 筛选时间
  actionSheetChange() {
    this.setData({
      actionSheetHidden: !this.data.actionSheetHidden
    })
  },
  showActionsheetHandle() {
    this.setData({
      actionSheetHidden: !this.data.actionSheetHidden
    })
  },
  bindItemTap(e) {
    const value = e.currentTarget.dataset.value
    this.setData({
      actionSheetHidden: true,
      sortType: value,
      totalCount: null,
    }, () => {
      this.pageData.page = 1
      this.getData();
    })
  },
  goFilterHandle() {
    wx.navigateTo({
      url: `/pages/leadslistsearch/leadslistsearch?resultData=${JSON.stringify(this.data.resultData)}`
    })
  },
  showAddTap() {
    this.setData({
      showAddFlag: true
    })
  },
  closeAddTap() {
    this.setData({
      showAddFlag: false
    })
  },
  posterHandle(e) {
    const { pattern } = e.currentTarget.dataset
    wx.showLoading({
      title: pattern == 'poster' ? '海报生成中' : "二维码生成中"
    });
    let params = {}
    params.url = api_get_qrcode;
    params.data = {
      page: 'pages/leadscollection/leadscollection',
      width: '150'
    };
    net.req(params).then((res) => {
      wx.hideLoading();
      const { code, data } = res;
      if (parseInt(code) === 0 && data) {
        this.setData({
          barcodeImgUrl: data.host + data.url,
          posterTag: true,
          pattern: pattern
        });
      } else {
        wx.showToast({
          title: e.msg || 'error',
          icon: 'none',
          duration: 2000
        })
      }
    });
  },
  hidePosterHandle() {
    this.setData({
      posterTag: false,
      showAddFlag: false
    })
  },
  // 手动添加客户
  goleadscollection() {
    wx.navigateTo({
      url: '/pages/leadscollection/leadscollection',
    })
  },
  initListCallBack() {
    this.setData({
      totalCount: null,
      showAddFlag: false,
    }, () => {
      this.pageData.page = 1
      this.getData();
    })
  },
  getResultDataCallack(data) {
    this.setData({
      resultData: data,
      totalCount: null,
      isFliter: Object.keys(data).length === 0 ? false : true

    }, () => {
      this.pageData.page = 1
      this.getData();
    })
  }
})