const {
  api_mobile_logout,
  api_upload_file,
  api_update_photo,
  api_get_user_info,
} = require("../../utils/api.js");
const { net } = require("../../utils/net.js");
const util = require("../../utils/util.js");

Page({
  data: {
    isLogin: false,
    data: {},
    mobile: "",
    phone: "400-898-6659",
  },
  onLoad: function (options) {
    let userInfo = util.getStorageSync("userInfo");
    if (userInfo) {
      this.setData(
        {
          data: userInfo,
          isLogin: true,
        },
        () => {
          this.setData({
            mobile: userInfo.mobile,
            // mobile: `${userInfo.mobile.slice(0, 3)}****${userInfo.mobile.slice(-4)}`
          });
        }
      );
    } else {
      this.setData({
        isLogin: false,
      });
      // 跳转到登录页面
      wx.navigateTo({
        url: "/pages/loginways/loginways",
      });
    }
  },
  onReady: function () {
    wx.setNavigationBarTitle({
      title: "我的",
    });
  },
  goLoginTap() {
    wx.reLaunch({
      url: "/pages/loginways/loginways",
    });
  },
  // 登出
  logout() {
    wx.showModal({
      title: "提示",
      content: "确认退出当前账号？",
      success: (res) => {
        if (res.confirm) {
          let params = {};
          params.url = api_mobile_logout;
          net.req(params).then((res) => {});
          wx.clearStorageSync();
          wx.showToast({
            title: "退出成功",
            icon: "none",
            duration: 1000,
          });
          setTimeout(() => {
            wx.reLaunch({
              url: "/pages/loginways/loginways",
            });
          }, 1000);
        }
      },
    });
  },
  // 打电话
  handleMakePhone() {
    let _this = this;
    let systemInfo = util.getStorageSync("systemInfo");
    if (!systemInfo) {
      systemInfo = wx.getSystemInfoSync();
      if (systemInfo) {
        wx.setStorageSync("systemInfo", systemInfo);
      }
    }
    let { system } = systemInfo;
    if (system.toLowerCase().indexOf("ios") !== -1) {
      wx.makePhoneCall({
        phoneNumber: _this.data.phone,
        success() {},
        fail() {},
        complete() {},
      });
    } else {
      wx.showActionSheet({
        itemList: [_this.data.phone],
        success(res) {
          if (res.tapIndex === 0) {
            wx.makePhoneCall({
              phoneNumber: _this.data.phone,
              success() {},
              fail() {},
              complete() {},
            });
          }
        },
      });
    }
  },
  changeUserPhoto() {
    const _this = this;
    wx.showActionSheet({
      itemList: ["从相册中", "拍照"],
      success(res) {
        if (res.tapIndex == 0) {
          _this.chooseImage("album");
        } else {
          _this.chooseImage("camera");
        }
      },
      fail(res) {},
    });
  },
  chooseImage(type) {
    const _this = this;
    wx.chooseImage({
      count: 1,
      sizeType: ["original", "compressed"],
      sourceType: [type],
      success(res) {
        // tempFilePath可以作为img标签的src属性显示图片
        _this.uploadImage(res.tempFilePaths[0]);
      },
    });
  },
  uploadImage(filePath) {
    wx.showLoading({
      title: "正在上传头像",
    });
    let params = {};
    params.url = api_upload_file;
    params.filePath = filePath;
    params.data = {
      project: "distributors",
      contentType: "user/head",
    };
    net.uploadFile(params).then(
      (res) => {
        const { host, url } = res.data;
        if (Array.isArray(url) && url.length) {
          const imgSrc = host + url[0];
          this.uploadImgUrlToServer(imgSrc);
        } else {
          wx.hideLoading();
        }
      },
      (err) => {
        wx.hideLoading();
      }
    );
  },

  uploadImgUrlToServer(imgUrl) {
    let params = {};
    params.url = api_update_photo;
    params.data = {
      avatar: imgUrl,
    };
    net.req(params).then((res) => {
      let userInfo = this.data.data;
      userInfo.avatar = imgUrl;
      userInfo.changeImg = true; // 标识用户修改了头像，在home的onShow页面需要用到
      this.setData({
        data: userInfo,
      });
      //获取页面栈
      wx.setStorageSync("userInfo", userInfo);
      wx.hideLoading();
    });
  },
  copyStaffCodeAction(e) {
    const { staffCode } = e.currentTarget.dataset;
    if (staffCode && staffCode.length) {
      wx.setClipboardData({
        data: staffCode,
        success(res) {},
      });
    }
  },
  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh: function () {
    const oldUserInfo = JSON.parse(JSON.stringify(this.data.data));
    let params = {};
    params.url = api_get_user_info;
    net.req(params).then((res) => {
      const newUserInfo = Object.assign(oldUserInfo, res.data);
      wx.setStorageSync("userInfo", newUserInfo);
      this.setData({
        data: newUserInfo,
      });
    });
    wx.stopPullDownRefresh();
  },
});
