const {
  net
} = require('../../utils/net.js');
const util = require('../../utils/util.js');
const {
  api_school_list
} = require('../../utils/api.js');

Page({
  /**
   * 页面的初始数据
   */
  data: {
    isLoading: true,
    countryId: "",
    cityId: "",
    allSchoolList: [],
    schoolList: [],
  },
  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    this.setData({
      countryId: options.countryId,
      cityId: options.cityId
    })
    this.loadSchoolList();
    this.debounceSearchInputChange = util.debounce(this.handleSearchInputChange);
  },
  // 获取学校列表
  loadSchoolList() {
    const { countryId, cityId } = this.data;
    let params = {};
    params.url = api_school_list;
    params.data = { countryId: countryId, cityId: cityId };
    return net.req(params, true).then(res => {
      const { code, data } = res;
      if (parseInt(code) === 0 && data.list && Array.isArray(data.list) && data.list.length) {
        this.setData({
          isLoading: false,
          allSchoolList: data.list,
          schoolList: data.list
        })
      } else {
        this.setData({
          isLoading: false,
          allSchoolList: [],
          schoolList: []
        })
      }
    }, e => {
      this.setData({
        isLoading: false,
        allSchoolList: [],
        schoolList: []
      })
    })
  },
  // 搜索学校输入框变化-实时搜索
  handleSearchInputChange(e) {
    const { cityId } = this.data;
    let value = e.detail;
    let params = {};
    params.url = api_school_list;
    value = value.trim();
    if (value && value.length) {
      params.data = {
        cityId: cityId,
        keyword: value
      };
      net.req(params, true).then(res => {
        const { code, data } = res;
        if (parseInt(code) === 0 && data.list && Array.isArray(data.list) && data.list.length) {
          this.setData({
            schoolList: data.list
          })
        } else {
          this.setData({
            schoolList: []
          })
        }
      },
        e => {
          this.setData({
            schoolList: []
          })
        }
      )
    } else {
      this.setData({
        schoolList: this.data.allSchoolList
      })
    }
  },
  // 选择学校
  handleClickSearchItem(e) {
    const item = e.detail;
    const schoolItem = { schoolId: item.id, schoolName: item.name };
    let eventChannel = this.getOpenerEventChannel();
    eventChannel.emit('selectedSchoolEvent', schoolItem);
    wx.navigateBack();
  },

  // 点击关闭按钮
  handleClickClose() {
    wx.navigateBack();
  },
})